from django.conf import settings
from django.forms import EmailField
from django.utils.translation import gettext_lazy as _

from dynamic_preferences.preferences import Section
from dynamic_preferences.types import LongStringPreference, StringPreference

from aleksis.core.registries import site_preferences_registry

paweljong = Section("paweljong", verbose_name=_("Paweljong"))


@site_preferences_registry.register
class EventNotificationRecipient(StringPreference):
    """Mail recipient for event nofications (e.g. registrations)."""

    section = paweljong
    name = "event_notification_recipient"
    default = settings.ADMINS[0][1]
    verbose_name = _("Mail recipient for event notifications")
    field_class = EmailField
    required = True


@site_preferences_registry.register
class EventInvoiceClientName(StringPreference):
    """Name to use for the client linked to invoices generated for events."""

    section = paweljong
    name = "event_invoice_client_name"
    default = "Teckids e.V."
    verbose_name = _("Name of client linked to invoices for events.")
    required = True


@site_preferences_registry.register
class EventInvoiceGroupName(StringPreference):
    """Name to use for the invoice group used for events."""

    section = paweljong
    name = "event_invoice_group_name"
    default = "Hack'n'Fun-Veranstaltungen"
    verbose_name = _("Name of invoice group used for events.")
    required = True


@site_preferences_registry.register
class EventRegistrationEmailParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the email step of the event registration wizard."""

    section = paweljong
    name = "event_registration_email_participant_help_text"
    verbose_name = _("Participant help text for email step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationRegisterParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the account registration step of the event registration wizard."""

    section = paweljong
    name = "event_registration_register_participant_help_text"
    verbose_name = _(
        "Participant help text for account registration step in event registration wizard."
    )
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationContactDetailsParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the contact details step of the event registration wizard."""

    section = paweljong
    name = "event_registration_contact_details_participant_help_text"
    verbose_name = _("Participant help text for contact details step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationGuardiansParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the guardians step of the event registration wizard."""

    section = paweljong
    name = "event_registration_guardians_participant_help_text"
    verbose_name = _("Participant help text for guardians step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationAdditionalParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the additional information step of the event registration wizard."""

    section = paweljong
    name = "event_registration_additional_participant_help_text"
    verbose_name = _(
        "Participant help text for additional information step in event registration wizard."
    )
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationFinancialParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the financial step of the event registration wizard."""

    section = paweljong
    name = "event_registration_financial_participant_help_text"
    verbose_name = _("Participant help text for financial step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationConsentParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the consent step of the event registration wizard."""

    section = paweljong
    name = "event_registration_consent_participant_help_text"
    verbose_name = _("Participant help text for consent step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationConfirmParticipantHelpText(LongStringPreference):
    """Help text to be displayed to participants during the confirmation step of the event registration wizard."""

    section = paweljong
    name = "event_registration_confirm_participant_help_text"
    verbose_name = _("Participant help text for confirmation step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationEmailGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the email step of the event registration wizard."""

    section = paweljong
    name = "event_registration_email_guardian_help_text"
    verbose_name = _("Guardian help text for email step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationRegisterGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the account registration step of the event registration wizard."""

    section = paweljong
    name = "event_registration_register_guardian_help_text"
    verbose_name = _(
        "Guardian help text for account registration step in event registration wizard."
    )
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationContactDetailsGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the contact details step of the event registration wizard."""

    section = paweljong
    name = "event_registration_contact_details_guardian_help_text"
    verbose_name = _("Guardian help text for contact details step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationGuardiansGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the guardians step of the event registration wizard."""

    section = paweljong
    name = "event_registration_guardians_guardian_help_text"
    verbose_name = _("Guardian help text for guardians step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationAdditionalGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the additional information step of the event registration wizard."""

    section = paweljong
    name = "event_registration_additional_guardian_help_text"
    verbose_name = _(
        "Guardian help text for additional information step in event registration wizard."
    )
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationFinancialGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the financial step of the event registration wizard."""

    section = paweljong
    name = "event_registration_financial_guardian_help_text"
    verbose_name = _("Guardian help text for financial step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationConsentGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the consent step of the event registration wizard."""

    section = paweljong
    name = "event_registration_consent_guardian_help_text"
    verbose_name = _("Guardian help text for consent step in event registration wizard.")
    default = ""
    required = False


@site_preferences_registry.register
class EventRegistrationConfirmGuardianHelpText(LongStringPreference):
    """Help text to be displayed to guardians during the confirmation step of the event registration wizard."""

    section = paweljong
    name = "event_registration_confirm_guardian_help_text"
    verbose_name = _("Guardian help text for confirmation step in event registration wizard.")
    default = ""
    required = False
